summaryrefslogtreecommitdiffstats
path: root/knode
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /knode
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knode')
-rw-r--r--knode/Makefile.am2
-rw-r--r--knode/articlewidget.cpp36
-rw-r--r--knode/articlewidget.h2
-rw-r--r--knode/headerview.cpp12
-rw-r--r--knode/knaccountmanager.cpp4
-rw-r--r--knode/knarticle.cpp4
-rw-r--r--knode/knarticle.h2
-rw-r--r--knode/knarticlefactory.cpp24
-rw-r--r--knode/knarticlefilter.cpp6
-rw-r--r--knode/knarticlemanager.cpp20
-rw-r--r--knode/kncollectionview.cpp2
-rw-r--r--knode/kncollectionviewitem.cpp2
-rw-r--r--knode/kncomposer.cpp96
-rw-r--r--knode/kncomposer.h4
-rw-r--r--knode/knconfig.cpp16
-rw-r--r--knode/knconfig.h2
-rw-r--r--knode/knconfigwidgets.cpp34
-rw-r--r--knode/knconvert.cpp2
-rw-r--r--knode/kndisplayedheader.cpp4
-rw-r--r--knode/knfilterdialog.cpp4
-rw-r--r--knode/knfiltermanager.cpp2
-rw-r--r--knode/knfolder.cpp6
-rw-r--r--knode/knfoldermanager.cpp10
-rw-r--r--knode/knglobals.cpp4
-rw-r--r--knode/knglobals.h4
-rw-r--r--knode/kngroup.cpp16
-rw-r--r--knode/kngroup.h2
-rw-r--r--knode/kngroupbrowser.cpp8
-rw-r--r--knode/kngroupdialog.cpp4
-rw-r--r--knode/kngroupmanager.cpp6
-rw-r--r--knode/kngroupmanager.h2
-rw-r--r--knode/kngrouppropdlg.cpp2
-rw-r--r--knode/kngroupselectdialog.cpp2
-rw-r--r--knode/knhdrviewitem.cpp6
-rw-r--r--knode/knhdrviewitem.h2
-rw-r--r--knode/knjobdata.cpp4
-rw-r--r--knode/knjobdata.h2
-rw-r--r--knode/knmainwidget.cpp50
-rw-r--r--knode/knmainwidget.h10
-rw-r--r--knode/knmemorymanager.cpp4
-rw-r--r--knode/knnetaccess.cpp48
-rw-r--r--knode/knnntpaccount.cpp2
-rw-r--r--knode/knnntpclient.cpp2
-rw-r--r--knode/knode.cpp4
-rw-r--r--knode/knode.h2
-rw-r--r--knode/knode_part.cpp8
-rw-r--r--knode/knode_part.h4
-rw-r--r--knode/knrangefilter.cpp2
-rw-r--r--knode/knsearchdialog.cpp4
-rw-r--r--knode/knserverinfo.cpp4
-rw-r--r--knode/knstringfilter.cpp10
-rw-r--r--knode/knstringfilter.h2
-rw-r--r--knode/knwidgets.cpp6
-rw-r--r--knode/knwidgets.h2
-rw-r--r--knode/smtpaccountwidget_base.ui6
-rw-r--r--knode/utilities.cpp8
56 files changed, 269 insertions, 269 deletions
diff --git a/knode/Makefile.am b/knode/Makefile.am
index f1763145..57b6481e 100644
--- a/knode/Makefile.am
+++ b/knode/Makefile.am
@@ -11,7 +11,7 @@ lib_LTLIBRARIES = libknodecommon.la
kde_module_LTLIBRARIES = kcm_knode.la libknodepart.la
libknodepart_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(KDE_RPATH) $(KDE_PLUGIN)
-libknodepart_la_LIBADD = libknodecommon.la
+libknodepart_la_LIBADD = libknodecommon.la $(LIB_QT) $(LIB_KDECORE) $(LIB_KDEUI) $(LIB_KIO) $(LIB_KPARTS) -lDCOP -L$(top_builddir)/libkdepim -lkdepim
SUBDIRS = pics filters
diff --git a/knode/articlewidget.h b/knode/articlewidget.h
index 2571642d..2d44fdfc 100644
--- a/knode/articlewidget.h
+++ b/knode/articlewidget.h
@@ -125,7 +125,7 @@ class ArticleWidget : public TQWidget, public KNJobConsumer {
/// displays the given error message in the viewer
void displayErrorMessage( const TQString &msg );
- /// display the message header (should be replaced by KMail's HeaderStyle class)
+ /// display the message header (should be tqreplaced by KMail's HeaderStyle class)
void displayHeader();
/** displays the given text block, including quote and signature handling
* @param lines A list of lines to display.
diff --git a/knode/knaccountmanager.cpp b/knode/knaccountmanager.cpp
index 167a49c6..76466ddb 100644
--- a/knode/knaccountmanager.cpp
+++ b/knode/knaccountmanager.cpp
@@ -223,7 +223,7 @@ void KNAccountManager::loadPasswordsAsync()
if ( !mWallet && !mWalletOpenFailed ) {
if ( knGlobals.top )
mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
- knGlobals.topWidget->topLevelWidget()->winId(),
+ knGlobals.topWidget->tqtopLevelWidget()->winId(),
Wallet::Asynchronous );
else
mWallet = Wallet::openWallet( Wallet::NetworkWallet(), 0, Wallet::Asynchronous );
@@ -263,7 +263,7 @@ KWallet::Wallet* KNAccountManager::wallet()
delete mWallet;
if ( knGlobals.top )
mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
- knGlobals.topWidget->topLevelWidget()->winId() );
+ knGlobals.topWidget->tqtopLevelWidget()->winId() );
else
mWallet = Wallet::openWallet( Wallet::NetworkWallet() );
diff --git a/knode/knarticle.cpp b/knode/knarticle.cpp
index fe475b1b..437639d1 100644
--- a/knode/knarticle.cpp
+++ b/knode/knarticle.cpp
@@ -209,7 +209,7 @@ void KNRemoteArticle::updateListItem()
i_tem->setExpandable( (threadMode() && hasVisibleFollowUps()) );
- i_tem->repaint(); //force repaint
+ i_tem->tqrepaint(); //force tqrepaint
}
@@ -435,7 +435,7 @@ KNAttachment::KNAttachment(Content *c)
KNAttachment::KNAttachment(KNLoadHelper *helper)
: c_ontent(0), l_oadHelper(helper), f_ile(helper->getFile()), i_sAttached(false), h_asChanged(true)
{
- setMimeType((KMimeMagic::self()->findFileType(f_ile->name()))->mimeType());
+ setMimeType((KMimeMagic::self()->tqfindFileType(f_ile->name()))->mimeType());
n_ame=helper->getURL().fileName();
}
diff --git a/knode/knarticle.h b/knode/knarticle.h
index 798742e1..e36bfdfe 100644
--- a/knode/knarticle.h
+++ b/knode/knarticle.h
@@ -35,7 +35,7 @@ class KNHdrViewItem;
class KNArticleCollection;
/** This class encapsulates a generic article. It provides all the
- usual headers of a RFC822-message. Further more it contains an
+ usual headers of a RFC822-message. Further more it tqcontains an
unique id and can store a pointer to a @ref TQListViewItem. It is
used as a base class for all visible articles. */
diff --git a/knode/knarticlefactory.cpp b/knode/knarticlefactory.cpp
index 410c2bf4..493e2e22 100644
--- a/knode/knarticlefactory.cpp
+++ b/knode/knarticlefactory.cpp
@@ -209,13 +209,13 @@ void KNArticleFactory::createReply(KNRemoteArticle *a, TQString selectedText, bo
TQString attribution=knGlobals.configManager()->postNewsComposer()->intro();
TQString name(a->from()->name());
if (name.isEmpty())
- name = TQString::fromLatin1(a->from()->email());
- attribution.replace(TQRegExp("%NAME"),name);
- attribution.replace(TQRegExp("%EMAIL"),TQString::fromLatin1(a->from()->email()));
- attribution.replace(TQRegExp("%DATE"),KGlobal::locale()->formatDateTime(a->date()->qdt(),false));
- attribution.replace(TQRegExp("%MSID"),a->messageID()->asUnicodeString());
- attribution.replace(TQRegExp("%GROUP"),g->groupname());
- attribution.replace(TQRegExp("%L"),"\n");
+ name = TQString::tqfromLatin1(a->from()->email());
+ attribution.tqreplace(TQRegExp("%NAME"),name);
+ attribution.tqreplace(TQRegExp("%EMAIL"),TQString::tqfromLatin1(a->from()->email()));
+ attribution.tqreplace(TQRegExp("%DATE"),KGlobal::locale()->formatDateTime(a->date()->qdt(),false));
+ attribution.tqreplace(TQRegExp("%MSID"),a->messageID()->asUnicodeString());
+ attribution.tqreplace(TQRegExp("%GROUP"),g->groupname());
+ attribution.tqreplace(TQRegExp("%L"),"\n");
attribution+="\n\n";
TQString quoted=attribution;
@@ -279,7 +279,7 @@ void KNArticleFactory::createForward(KNArticle *a)
bool incAtt = ( !knGlobals.configManager()->postNewsTechnical()->useExternalMailer() &&
ct->isMultipart() && ct->isSubtype("mixed") &&
KMessageBox::Yes == KMessageBox::questionYesNo(knGlobals.topWidget,
- i18n("This article contains attachments. Do you want them to be forwarded as well?"), TQString::null, i18n("Forward"), i18n("Do Not Forward"))
+ i18n("This article tqcontains attachments. Do you want them to be forwarded as well?"), TQString::null, i18n("Forward"), i18n("Do Not Forward"))
);
if (knGlobals.configManager()->postNewsTechnical()->useOwnCharset())
@@ -419,7 +419,7 @@ void KNArticleFactory::createCancel(KNArticle *a)
art->lines()->setNumberOfLines(1);
//body
- art->fromUnicodeString(TQString::fromLatin1("cancel by original author\n"));
+ art->fromUnicodeString(TQString::tqfromLatin1("cancel by original author\n"));
//assemble
art->assemble();
@@ -875,9 +875,9 @@ KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, TQString &sig, T
if(origPost) {
TQString name(origPost->from()->name());
if (name.isEmpty())
- name = TQString::fromLatin1(origPost->from()->email());
- value.replace(TQRegExp("%NAME"), name);
- value.replace(TQRegExp("%EMAIL"), TQString::fromLatin1(origPost->from()->email()));
+ name = TQString::tqfromLatin1(origPost->from()->email());
+ value.tqreplace(TQRegExp("%NAME"), name);
+ value.tqreplace(TQRegExp("%EMAIL"), TQString::tqfromLatin1(origPost->from()->email()));
}
else
if(value.find("%NAME") != -1 || value.find("%EMAIL") != -1)
diff --git a/knode/knarticlefilter.cpp b/knode/knarticlefilter.cpp
index 60d0e032..bb2f2338 100644
--- a/knode/knarticlefilter.cpp
+++ b/knode/knarticlefilter.cpp
@@ -189,7 +189,7 @@ void KNArticleFilter::doFilter(KNGroup *g)
if(!l_oaded) load();
- subject.expand(g); // replace placeholders
+ subject.expand(g); // tqreplace placeholders
from.expand(g);
messageId.expand(g);
references.expand(g);
@@ -287,7 +287,7 @@ void KNArticleFilter::doFilter(KNFolder *f)
if(!l_oaded) load();
- subject.expand(0); // replace placeholders
+ subject.expand(0); // tqreplace placeholders
from.expand(0);
messageId.expand(0);
references.expand(0);
@@ -324,7 +324,7 @@ void KNArticleFilter::setTranslatedName(const TQString &s)
bool retranslated = false;
for (const char **c=defFil;(*c)!=0;c++) // ok, try if it matches any of the standard filter names
if (s==i18n("default filter name",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
diff --git a/knode/knarticlemanager.cpp b/knode/knarticlemanager.cpp
index 86bcd8df..d1aec96a 100644
--- a/knode/knarticlemanager.cpp
+++ b/knode/knarticlemanager.cpp
@@ -99,7 +99,7 @@ void KNArticleManager::saveArticleToFile(KNArticle *a, TQWidget *parent)
else
s.append(' ');
fName = s.simplifyWhiteSpace();
- fName.replace(TQRegExp("[\\s]"),"_");
+ fName.tqreplace(TQRegExp("[\\s]"),"_");
KNSaveHelper helper(fName,parent);
TQFile *file = helper.getFile(i18n("Save Article"));
@@ -186,7 +186,7 @@ void KNArticleManager::showHdrs(bool clear)
v_iew->clear();
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Creating list..."));
+ knGlobals.seStatusMsg(i18n(" Creating list..."));
knGlobals.top->secureProcessEvents();
if(g_roup) {
@@ -324,7 +324,7 @@ void KNArticleManager::showHdrs(bool clear)
knGlobals.top->articleViewer()->setArticle( 0 );
}
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
updateStatusString();
knGlobals.top->setCursorBusy(false);
}
@@ -991,25 +991,25 @@ void KNArticleManager::updateStatusString()
if (g_roup->status()==KNGroup::moderated)
name += i18n(" (moderated)");
- knGlobals.setStatusMsg(i18n(" %1: %2 new , %3 displayed")
+ knGlobals.seStatusMsg(i18n(" %1: %2 new , %3 displayed")
.arg(name).arg(g_roup->newCount()).arg(displCnt),SB_GROUP);
if(f_ilter)
- knGlobals.setStatusMsg(i18n(" Filter: %1").arg(f_ilter->translatedName()), SB_FILTER);
+ knGlobals.seStatusMsg(i18n(" Filter: %1").arg(f_ilter->translatedName()), SB_FILTER);
else
- knGlobals.setStatusMsg(TQString::null, SB_FILTER);
+ knGlobals.seStatusMsg(TQString::null, SB_FILTER);
}
else if(f_older) {
if(f_ilter)
displCnt=f_ilter->count();
else
displCnt=f_older->count();
- knGlobals.setStatusMsg(i18n(" %1: %2 displayed")
+ knGlobals.seStatusMsg(i18n(" %1: %2 displayed")
.arg(f_older->name()).arg(displCnt), SB_GROUP);
- knGlobals.setStatusMsg(TQString::null, SB_FILTER);
+ knGlobals.seStatusMsg(TQString::null, SB_FILTER);
} else {
- knGlobals.setStatusMsg(TQString::null, SB_GROUP);
- knGlobals.setStatusMsg(TQString::null, SB_FILTER);
+ knGlobals.seStatusMsg(TQString::null, SB_GROUP);
+ knGlobals.seStatusMsg(TQString::null, SB_FILTER);
}
}
diff --git a/knode/kncollectionview.cpp b/knode/kncollectionview.cpp
index 63542cad..3bbb5237 100644
--- a/knode/kncollectionview.cpp
+++ b/knode/kncollectionview.cpp
@@ -93,7 +93,7 @@ void KNCollectionView::readConfig()
KConfig *conf = knGlobals.config();
conf->setGroup( "GroupView" );
- // execute the listview layout stuff only once
+ // execute the listview tqlayout stuff only once
static bool initDone = false;
if (!initDone) {
initDone = true;
diff --git a/knode/kncollectionviewitem.cpp b/knode/kncollectionviewitem.cpp
index 8fed1f96..35f2ae2c 100644
--- a/knode/kncollectionviewitem.cpp
+++ b/knode/kncollectionviewitem.cpp
@@ -160,7 +160,7 @@ TQString KNCollectionViewItem::squeezeFolderName( const TQString &text,
nextPos = t.find('.', curPos);
if ( nextPos != -1 ) {
temp = t[curPos];
- t.replace( curPos, nextPos - curPos, temp );
+ t.tqreplace( curPos, nextPos - curPos, temp );
curPos += 2;
}
}
diff --git a/knode/kncomposer.cpp b/knode/kncomposer.cpp
index 53520e29..533ad356 100644
--- a/knode/kncomposer.cpp
+++ b/knode/kncomposer.cpp
@@ -236,9 +236,9 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
KStdAction::selectAll(this, TQT_SLOT(slotSelectAll()), actionCollection());
KStdAction::find(v_iew->e_dit, TQT_SLOT(slotFind()), actionCollection());
- KStdAction::findNext(v_iew->e_dit, TQT_SLOT(slotSearchAgain()), actionCollection());
+ KStdAction::tqfindNext(v_iew->e_dit, TQT_SLOT(slotSearchAgain()), actionCollection());
- KStdAction::replace(v_iew->e_dit, TQT_SLOT(slotReplace()), actionCollection());
+ KStdAction::tqreplace(v_iew->e_dit, TQT_SLOT(slotReplace()), actionCollection());
//attach menu
new KAction(i18n("Append &Signature"), 0 , this, TQT_SLOT(slotAppendSig()),
@@ -343,7 +343,7 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
if (firstEdit) { // now we place the cursor at the end of the quoted text / below the attribution line
if (knGlobals.configManager()->postNewsComposer()->cursorOnTop()) {
- int numLines = knGlobals.configManager()->postNewsComposer()->intro().contains("%L");
+ int numLines = knGlobals.configManager()->postNewsComposer()->intro().tqcontains("%L");
v_iew->e_dit->setCursorPosition(numLines+1,0);
}
else
@@ -411,7 +411,7 @@ int KNComposer::listOfResultOfCheckWord( const TQStringList & lst , const TQStri
createGUI("kncomposerui.rc", false);
unplugActionList("spell_result" );
m_listAction.clear();
- if ( !lst.contains( selectWord ) )
+ if ( !lst.tqcontains( selectWord ) )
{
TQStringList::ConstIterator it = lst.begin();
for ( ; it != lst.end() ; ++it )
@@ -432,7 +432,7 @@ int KNComposer::listOfResultOfCheckWord( const TQStringList & lst , const TQStri
void KNComposer::slotUndo()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -443,7 +443,7 @@ void KNComposer::slotUndo()
void KNComposer::slotRedo()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -454,7 +454,7 @@ void KNComposer::slotRedo()
void KNComposer::slotCut()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -466,7 +466,7 @@ void KNComposer::slotCut()
void KNComposer::slotCopy()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -480,7 +480,7 @@ void KNComposer::slotCopy()
void KNComposer::slotPaste()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -492,7 +492,7 @@ void KNComposer::slotPaste()
void KNComposer::slotSelectAll()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("TQLineEdit"))
@@ -534,7 +534,7 @@ void KNComposer::setMessageMode(MessageMode mode)
if (m_ode == news_mail) {
TQString s = v_iew->e_dit->textLine(0);
- if (!s.contains(i18n("<posted & mailed>")))
+ if (!s.tqcontains(i18n("<posted & mailed>")))
v_iew->e_dit->insertAt(i18n("<posted & mailed>\n\n"),0,0);
} else {
if (v_iew->e_dit->textLine(0)==i18n("<posted & mailed>")) {
@@ -658,7 +658,7 @@ bool KNComposer::hasValidData()
}
if (n_eeds8Bit && (c_harset.lower()=="us-ascii")) {
- KMessageBox::sorry(this, i18n("Your message contains characters which are not included\nin the \"us-ascii\" character set; please choose\na suitable character set from the \"Options\" menu."));
+ KMessageBox::sorry(this, i18n("Your message tqcontains characters which are not included\nin the \"us-ascii\" character set; please choose\na suitable character set from the \"Options\" menu."));
return false;
}
@@ -682,7 +682,7 @@ bool KNComposer::hasValidData()
if (longLine)
if (!(KMessageBox::warningYesNo( this,
- i18n("Your article contains lines longer than 80 characters.\n"
+ i18n("Your article tqcontains lines longer than 80 characters.\n"
"Do you want to re-edit the article or send it anyway?"),
TQString::null, i18n("&Send"),
i18n("edit article","&Edit")) == KMessageBox::Yes))
@@ -957,7 +957,7 @@ void KNComposer::initData(const TQString &text)
}
-// inserts at cursor position if clear is false, replaces content otherwise
+// inserts at cursor position if clear is false, tqreplaces content otherwise
// puts the file content into a box if box==true
// "file" is already open for reading
void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitle)
@@ -969,7 +969,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
ts.setCodec(codec);
if (box)
- temp = TQString::fromLatin1(",----[ %1 ]\n").arg(boxTitle);
+ temp = TQString::tqfromLatin1(",----[ %1 ]\n").arg(boxTitle);
if (box && (v_iew->e_dit->wordWrap()!=TQMultiLineEdit::NoWrap)) {
int wrapAt = v_iew->e_dit->wrapColumnOrWidth();
@@ -993,7 +993,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
}
if (box)
- temp += TQString::fromLatin1("`----");
+ temp += TQString::tqfromLatin1("`----");
if(clear)
v_iew->e_dit->setText(temp);
@@ -1173,7 +1173,7 @@ void KNComposer::slotToggleDoMail()
if (knGlobals.configManager()->postNewsTechnical()->useExternalMailer()) {
TQString s = v_iew->e_dit->textLine(0);
- if (!s.contains(i18n("<posted & mailed>")))
+ if (!s.tqcontains(i18n("<posted & mailed>")))
v_iew->e_dit->insertAt(i18n("<posted & mailed>\n\n"),0,0);
TQString tmp;
TQStringList textLines = v_iew->e_dit->processedText();
@@ -1231,7 +1231,7 @@ void KNComposer::slotToggleWordWrap()
void KNComposer::slotUndoRewrap()
{
- if (KMessageBox::warningContinueCancel( this, i18n("This will replace all text you have written.")) == KMessageBox::Continue) {
+ if (KMessageBox::warningContinueCancel( this, i18n("This will tqreplace all text you have written.")) == KMessageBox::Continue) {
v_iew->e_dit->setText(u_nwraped);
slotAppendSig();
}
@@ -1293,8 +1293,8 @@ void KNComposer::slotExternalEditor()
TQStringList command = TQStringList::split(' ',editorCommand);
bool filenameAdded=false;
for ( TQStringList::Iterator it = command.begin(); it != command.end(); ++it ) {
- if ((*it).contains("%f")) {
- (*it).replace(TQRegExp("%f"),e_ditorTempfile->name());
+ if ((*it).tqcontains("%f")) {
+ (*it).tqreplace(TQRegExp("%f"),e_ditorTempfile->name());
filenameAdded=true;
}
(*e_xternalEditor) << (*it);
@@ -1422,10 +1422,10 @@ void KNComposer::slotNewToolbarConfig()
void KNComposer::slotSubjectChanged(const TQString &t)
{
- // replace newlines
+ // tqreplace newlines
TQString subject = t;
- subject.replace( '\n', ' ' );
- subject.replace( '\r', ' ' );
+ subject.tqreplace( '\n', ' ' );
+ subject.tqreplace( '\r', ' ' );
if ( subject != t ) // setText() sets the cursor to the end
v_iew->s_ubject->setText( subject );
// update caption
@@ -1447,7 +1447,7 @@ void KNComposer::slotGroupsChanged(const TQString &t)
split.init(t.latin1(), ",");
splitOk=split.first();
while(splitOk) {
- v_iew->f_up2->insertItem(TQString::fromLatin1(split.string()));
+ v_iew->f_up2->insertItem(TQString::tqfromLatin1(split.string()));
splitOk=split.next();
}
v_iew->f_up2->insertItem("");
@@ -1643,7 +1643,7 @@ void KNComposer::slotSpellFinished()
{
a_ctExternalEditor->setEnabled(true);
a_ctSpellCheck->setEnabled(true);
- KSpell::spellStatus status=s_pellChecker->status();
+ KSpell::spelltqStatus status=s_pellChecker->status();
delete s_pellChecker;
s_pellChecker=0;
@@ -1998,7 +1998,7 @@ KNComposer::Editor::Editor(KNComposer::ComposerView *_composerView, KNComposer *
spell = 0L;
installEventFilter(this);
KCursor::setAutoHideCursor( this, true, true );
- m_bound = TQRegExp( TQString::fromLatin1("[\\s\\W]") );
+ m_bound = TQRegExp( TQString::tqfromLatin1("[\\s\\W]") );
}
@@ -2052,13 +2052,13 @@ bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
lastSpace = paraText.length();
TQString word = paraText.mid( firstSpace, lastSpace - firstSpace );
//Continue if this word was misspelled
- if( !word.isEmpty() && m_replacements.contains( word ) )
+ if( !word.isEmpty() && m_tqreplacements.tqcontains( word ) )
{
KPopupMenu p;
p.insertTitle( i18n("Suggestions") );
//Add the suggestions to the popup menu
- TQStringList reps = m_replacements[word];
+ TQStringList reps = m_tqreplacements[word];
if( reps.count() > 0 )
{
int listPos = 0;
@@ -2081,11 +2081,11 @@ bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
int parIdx = 1, txtIdx = 1;
getCursorPosition(&parIdx, &txtIdx);
setSelection(para, firstSpace, para, lastSpace);
- insert(m_replacements[word][id]);
+ insert(m_tqreplacements[word][id]);
// Restore the cursor position; if the cursor was behind the
// misspelled word then adjust the cursor position
if ( para == parIdx && txtIdx >= lastSpace )
- txtIdx += m_replacements[word][id].length() - word.length();
+ txtIdx += m_tqreplacements[word][id].length() - word.length();
setCursorPosition(parIdx, txtIdx);
}
//Cancel original event
@@ -2099,7 +2099,7 @@ bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
void KNComposer::Editor::slotAddSuggestion( const TQString &text, const TQStringList &lst, unsigned int )
{
- m_replacements[text] = lst;
+ m_tqreplacements[text] = lst;
}
// expand tabs to avoid the "tab-damage",
@@ -2137,12 +2137,12 @@ TQStringList KNComposer::Editor::processedText()
}
}
- TQString replacement;
+ TQString tqreplacement;
int tabPos;
for (TQStringList::Iterator it = ret.begin(); it != ret.end(); ++it ) {
while ((tabPos=(*it).find('\t'))!=-1) {
- replacement.fill(TQChar(' '), 8-(tabPos%8));
- (*it).replace(tabPos, 1, replacement);
+ tqreplacement.fill(TQChar(' '), 8-(tabPos%8));
+ (*it).tqreplace(tabPos, 1, tqreplacement);
}
}
@@ -2159,7 +2159,7 @@ void KNComposer::Editor::slotPasteAsQuotation()
s[i] = ' ';
}
s.prepend("> ");
- s.replace(TQRegExp("\n"),"\n> ");
+ s.tqreplace(TQRegExp("\n"),"\n> ");
insert(s);
}
}
@@ -2177,7 +2177,7 @@ void KNComposer::Editor::slotSearchAgain()
void KNComposer::Editor::slotReplace()
{
- replace();
+ tqreplace();
}
@@ -2186,7 +2186,7 @@ void KNComposer::Editor::slotAddQuotes()
if (hasMarkedText()) {
TQString s = markedText();
s.prepend("> ");
- s.replace(TQRegExp("\n"),"\n> ");
+ s.tqreplace(TQRegExp("\n"),"\n> ");
insert(s);
} else {
int l = currentLine();
@@ -2206,7 +2206,7 @@ void KNComposer::Editor::slotRemoveQuotes()
TQString s = markedText();
if (s.left(2) == "> ")
s.remove(0,2);
- s.replace(TQRegExp("\n> "),"\n");
+ s.tqreplace(TQRegExp("\n> "),"\n");
insert(s);
} else {
int l = currentLine();
@@ -2227,13 +2227,13 @@ void KNComposer::Editor::slotAddBox()
if (hasMarkedText()) {
TQString s = markedText();
s.prepend(",----[ ]\n");
- s.replace(TQRegExp("\n"),"\n| ");
+ s.tqreplace(TQRegExp("\n"),"\n| ");
s.append("\n`----");
insert(s);
} else {
int l = currentLine();
int c = currentColumn();
- TQString s = TQString::fromLatin1(",----[ ]\n| %1\n`----").arg(textLine(l));
+ TQString s = TQString::tqfromLatin1(",----[ ]\n| %1\n`----").arg(textLine(l));
insertLine(s,l);
removeLine(l+3);
setCursorPosition(l+1,c+2);
@@ -2244,10 +2244,10 @@ void KNComposer::Editor::slotAddBox()
void KNComposer::Editor::slotRemoveBox()
{
if (hasMarkedText()) {
- TQString s = TQString::fromLatin1("\n") + markedText() + TQString::fromLatin1("\n");
- s.replace(TQRegExp("\n,----[^\n]*\n"),"\n");
- s.replace(TQRegExp("\n| "),"\n");
- s.replace(TQRegExp("\n`----[^\n]*\n"),"\n");
+ TQString s = TQString::tqfromLatin1("\n") + markedText() + TQString::tqfromLatin1("\n");
+ s.tqreplace(TQRegExp("\n,----[^\n]*\n"),"\n");
+ s.tqreplace(TQRegExp("\n| "),"\n");
+ s.tqreplace(TQRegExp("\n`----[^\n]*\n"),"\n");
s.remove(0,1);
s.truncate(s.length()-1);
insert(s);
@@ -2297,7 +2297,7 @@ void KNComposer::Editor::slotRemoveBox()
setCursorPosition(l,c-2);
setAutoUpdate(true);
- repaint(false);
+ tqrepaint(false);
}
}
@@ -2368,7 +2368,7 @@ void KNComposer::Editor::keyPressEvent ( TQKeyEvent *e)
&& newLine[leadingWhiteSpaceCount].isSpace() ) {
++leadingWhiteSpaceCount;
}
- newLine = newLine.replace( 0, leadingWhiteSpaceCount,
+ newLine = newLine.tqreplace( 0, leadingWhiteSpaceCount,
lineText.left( bot ) );
removeParagraph( line + 1 );
insertParagraph( newLine, line + 1 );
@@ -2423,7 +2423,7 @@ void KNComposer::Editor::slotSpellDone(const TQString &/*newtext*/)
void KNComposer::Editor::slotSpellFinished()
{
- KSpell::spellStatus status=spell->status();
+ KSpell::spelltqStatus status=spell->status();
delete spell;
spell=0;
@@ -2604,7 +2604,7 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
this, TQT_SLOT(slotMimeTypeTextChanged(const TQString&)));
//finish GUI
- setFixedHeight(sizeHint().height());
+ setFixedHeight(tqsizeHint().height());
KNHelper::restoreWindowSize("attProperties", this, TQSize(300,250));
setHelp("anc-knode-editor-advanced");
}
diff --git a/knode/kncomposer.h b/knode/kncomposer.h
index b1c1c12a..05d6de0a 100644
--- a/knode/kncomposer.h
+++ b/knode/kncomposer.h
@@ -68,7 +68,7 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
//set data from the given article
void initData(const TQString &text);
- // inserts at cursor position if clear is false, replaces content otherwise
+ // inserts at cursor position if clear is false, tqreplaces content otherwise
// puts the file content into a box if box==true
// "file" is already open for reading
void insertFile(TQFile *file, bool clear=false, bool box=false, TQString boxTitle=TQString::null);
@@ -295,7 +295,7 @@ private:
KNComposer *m_composer;
KNComposer::ComposerView *m_composerView;
KSpell *spell;
- TQMap<TQString,TQStringList> m_replacements;
+ TQMap<TQString,TQStringList> m_tqreplacements;
TQRegExp m_bound;
};
diff --git a/knode/knconfig.cpp b/knode/knconfig.cpp
index 85606d89..cfeb8f00 100644
--- a/knode/knconfig.cpp
+++ b/knode/knconfig.cpp
@@ -149,7 +149,7 @@ TQString KNConfig::Identity::getSignature()
else
s_igContents = s_igText;
- if (!s_igContents.isEmpty() && !s_igContents.contains("\n-- \n") && !(s_igContents.left(4) == "-- \n"))
+ if (!s_igContents.isEmpty() && !s_igContents.tqcontains("\n-- \n") && !(s_igContents.left(4) == "-- \n"))
s_igContents.prepend("-- \n");
return s_igContents;
@@ -942,11 +942,11 @@ void KNConfig::PostNewsTechnical::save()
conf->setGroup("POSTNEWS");
conf->writeEntry("ComposerCharsets", c_omposerCharsets);
- conf->writeEntry("Charset", TQString::fromLatin1(c_harset));
+ conf->writeEntry("Charset", TQString::tqfromLatin1(c_harset));
conf->writeEntry("8BitEncoding", a_llow8BitBody);
conf->writeEntry("UseOwnCharset", u_seOwnCharset);
conf->writeEntry("generateMId", g_enerateMID);
- conf->writeEntry("MIdhost", TQString::fromLatin1(h_ostname));
+ conf->writeEntry("MIdhost", TQString::tqfromLatin1(h_ostname));
conf->writeEntry("dontIncludeUA", d_ontIncludeUA);
conf->writeEntry("useExternalMailer", u_seExternalMailer);
@@ -1100,7 +1100,7 @@ KNConfig::Cleanup::Cleanup( bool global ) :
// default values for new accounts / groups
d_oExpire( true ), r_emoveUnavailable( true ), p_reserveThr( true ),
e_xpireInterval( 5 ), r_eadMaxAge( 10 ), u_nreadMaxAge( 15 ),
- mGlobal(global), mDefault(!global), mLastExpDate( TQDate::currentDate() )
+ mGlobal(global), mDefault(!global), mLastExpDate( TQDate::tqcurrentDate() )
{
if (mGlobal) {
KConfig *conf = knGlobals.config();
@@ -1174,7 +1174,7 @@ bool KNConfig::Cleanup::expireToday()
if (!d_oExpire)
return false;
- TQDate today = TQDate::currentDate();
+ TQDate today = TQDate::tqcurrentDate();
if (mLastExpDate == today)
return false;
@@ -1184,7 +1184,7 @@ bool KNConfig::Cleanup::expireToday()
void KNConfig::Cleanup::setLastExpireDate()
{
- mLastExpDate = TQDateTime::currentDateTime();
+ mLastExpDate = TQDateTime::tqcurrentDateTime();
}
@@ -1193,7 +1193,7 @@ bool KNConfig::Cleanup::compactToday()
if (!d_oCompact)
return false;
- TQDate today = TQDate::currentDate();
+ TQDate today = TQDate::tqcurrentDate();
if (mLastCompDate == today)
return false;
@@ -1203,7 +1203,7 @@ bool KNConfig::Cleanup::compactToday()
void KNConfig::Cleanup::setLastCompactDate()
{
- mLastCompDate = TQDateTime::currentDateTime();
+ mLastCompDate = TQDateTime::tqcurrentDateTime();
}
diff --git a/knode/knconfig.h b/knode/knconfig.h
index e2aa682b..6bca3ab1 100644
--- a/knode/knconfig.h
+++ b/knode/knconfig.h
@@ -390,7 +390,7 @@ class KDE_EXPORT XHeader {
TQCString name() { return n_ame; }
TQString value() { return v_alue; }
- TQString header() { return (TQString::fromLatin1(("X-"+n_ame+": "))+v_alue); }
+ TQString header() { return (TQString::tqfromLatin1(("X-"+n_ame+": "))+v_alue); }
protected:
TQCString n_ame;
diff --git a/knode/knconfigwidgets.cpp b/knode/knconfigwidgets.cpp
index 91fba601..d70ebfa4 100644
--- a/knode/knconfigwidgets.cpp
+++ b/knode/knconfigwidgets.cpp
@@ -213,7 +213,7 @@ void KNConfig::IdentityWidget::save()
d_ata->s_igningKey = s_igningKey->keyIDs().first();
d_ata->u_seSigFile=s_igFile->isChecked();
d_ata->u_seSigGenerator=s_igGenerator->isChecked();
- d_ata->s_igPath=c_ompletion->replacedPath(s_ig->text());
+ d_ata->s_igPath=c_ompletion->tqreplacedPath(s_ig->text());
d_ata->s_igText=s_igEditor->text();
if(d_ata->isGlobal())
@@ -242,7 +242,7 @@ void KNConfig::IdentityWidget::slotSignatureType(int type)
void KNConfig::IdentityWidget::slotSignatureChoose()
{
- TQString tmp=KFileDialog::getOpenFileName(c_ompletion->replacedPath(s_ig->text()),TQString::null,this,i18n("Choose Signature"));
+ TQString tmp=KFileDialog::getOpenFileName(c_ompletion->tqreplacedPath(s_ig->text()),TQString::null,this,i18n("Choose Signature"));
if(!tmp.isEmpty()) s_ig->setText(tmp);
emit changed( true );
}
@@ -250,7 +250,7 @@ void KNConfig::IdentityWidget::slotSignatureChoose()
void KNConfig::IdentityWidget::slotSignatureEdit()
{
- TQString fileName = c_ompletion->replacedPath(s_ig->text()).stripWhiteSpace();
+ TQString fileName = c_ompletion->tqreplacedPath(s_ig->text()).stripWhiteSpace();
if (fileName.isEmpty()) {
KMessageBox::sorry(this, i18n("You must specify a filename."));
@@ -561,7 +561,7 @@ KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidge
connect( knGlobals.accountManager(), TQT_SIGNAL(passwordsChanged()), TQT_SLOT(slotPasswordChanged()) );
- KNHelper::restoreWindowSize("accNewsPropDLG", this, sizeHint());
+ KNHelper::restoreWindowSize("accNewsPropDLG", this, tqsizeHint());
setHelp("anc-setting-the-news-account");
}
@@ -896,7 +896,7 @@ void KNConfig::AppearanceWidget::defaults()
colorItem->setColor(d_ata->defaultColor(i));
}
c_List->triggerUpdate(true);
- c_List->repaint(true);
+ c_List->tqrepaint(true);
// default fonts
FontListItem *fontItem;
@@ -1548,8 +1548,8 @@ KNConfig::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog(KNDisplayedHeader
v_alueCB[i]->setChecked(h->flag(i+4));
}
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("accReadHdrPropDLG", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("accReadHdrPropDLG", this, tqsizeHint());
connect(n_ameE, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotNameChanged(const TQString&)));
@@ -2138,8 +2138,8 @@ KNConfig::XHeaderConfDialog::XHeaderConfDialog(const TQString &h, TQWidget *p, c
v_alue->setText(h.mid(pos, h.length()-pos));
}
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("XHeaderDlg", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("XHeaderDlg", this, tqsizeHint());
n_ame->setFocus();
}
@@ -2157,7 +2157,7 @@ TQString KNConfig::XHeaderConfDialog::result()
{
TQString value = v_alue->text();
// just in case someone pastes a newline
- value.replace( '\n', ' ' );
+ value.tqreplace( '\n', ' ' );
return TQString( "X-%1: %2" ).arg( n_ame->text() ).arg( value );
}
@@ -2237,7 +2237,7 @@ KNConfig::PostNewsComposerWidget::PostNewsComposerWidget( PostNewsComposer *d, T
connect(e_ditor, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(changed()));
editorL->addWidget(btn,1,2);
- editorL->addMultiCellWidget(new TQLabel(i18n("%f will be replaced with the filename to edit."), editorB),2,2,0,2);
+ editorL->addMultiCellWidget(new TQLabel(i18n("%f will be tqreplaced with the filename to edit."), editorB),2,2,0,2);
e_xternCB=new TQCheckBox(i18n("Start exte&rnal editor automatically"), editorB);
editorL->addMultiCellWidget(e_xternCB, 3,3,0,2);
@@ -2373,10 +2373,10 @@ KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *paren
mExpGroup = new TQGroupBox( i18n("Newsgroup Cleanup Settings"), this );
mExpGroup->setColumnLayout(0, Qt::Vertical );
- mExpGroup->layout()->setSpacing( KDialog::spacingHint() );
- mExpGroup->layout()->setMargin( KDialog::marginHint() );
+ mExpGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
+ mExpGroup->tqlayout()->setMargin( KDialog::marginHint() );
top->addWidget( mExpGroup );
- TQGridLayout *grid = new TQGridLayout( mExpGroup->layout(), 7, 2 );
+ TQGridLayout *grid = new TQGridLayout( mExpGroup->tqlayout(), 7, 2 );
grid->setRowSpacing( 0, KDialog::spacingHint() );
@@ -2482,11 +2482,11 @@ KNConfig::CleanupWidget::CleanupWidget( TQWidget *p, const char *n ) :
TQGroupBox *foldersB=new TQGroupBox(i18n("Folders"), this);
foldersB->setColumnLayout(0, Qt::Vertical );
- foldersB->layout()->setSpacing( KDialog::spacingHint() );
- foldersB->layout()->setMargin( KDialog::marginHint() );
+ foldersB->tqlayout()->setSpacing( KDialog::spacingHint() );
+ foldersB->tqlayout()->setMargin( KDialog::marginHint() );
topL->addWidget(foldersB);
- TQGridLayout *foldersL=new TQGridLayout(foldersB->layout(), 3,2);
+ TQGridLayout *foldersL=new TQGridLayout(foldersB->tqlayout(), 3,2);
foldersL->setRowSpacing( 0, KDialog::spacingHint() );
diff --git a/knode/knconvert.cpp b/knode/knconvert.cpp
index 8fdb4890..ce25167e 100644
--- a/knode/knconvert.cpp
+++ b/knode/knconvert.cpp
@@ -96,7 +96,7 @@ will be created before the conversion starts.").arg(KNODE_VERSION), w_1);
w_2=new TQLabel(s_tack);
w_2->setText(i18n("<b>Converting, please wait...</b>"));
- w_2->setAlignment(AlignCenter);
+ w_2->tqsetAlignment(AlignCenter);
s_tack->addWidget(w_2, 2);
w_3=new TQWidget(s_tack);
diff --git a/knode/kndisplayedheader.cpp b/knode/kndisplayedheader.cpp
index cf25d57e..da8b1a2c 100644
--- a/knode/kndisplayedheader.cpp
+++ b/knode/kndisplayedheader.cpp
@@ -107,7 +107,7 @@ void KNDisplayedHeader::setTranslatedName(const TQString &s)
bool retranslated = false;
for (const char **c=predef;(*c)!=0;c++) { // ok, first the standard header names
if (s==i18n("collection of article headers",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
@@ -116,7 +116,7 @@ void KNDisplayedHeader::setTranslatedName(const TQString &s)
if (!retranslated) {
for (const char **c=disp;(*c)!=0;c++) // now our standard display names
if (s==i18n("collection of article headers",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
diff --git a/knode/knfilterdialog.cpp b/knode/knfilterdialog.cpp
index e9ebf66e..f0151766 100644
--- a/knode/knfilterdialog.cpp
+++ b/knode/knfilterdialog.cpp
@@ -74,8 +74,8 @@ KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *parent, const char
fw->messageId->setFilter(f->messageId);
fw->references->setFilter(f->references);
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("filterDLG", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("filterDLG", this, tqsizeHint());
setHelp("anc-using-filters");
connect( fname, TQT_SIGNAL( textChanged ( const TQString & )), this, TQT_SLOT( slotTextChanged( const TQString & )));
diff --git a/knode/knfiltermanager.cpp b/knode/knfiltermanager.cpp
index be57996f..9ea8d7ac 100644
--- a/knode/knfiltermanager.cpp
+++ b/knode/knfiltermanager.cpp
@@ -205,7 +205,7 @@ void KNFilterManager::addFilter(KNArticleFilter *f)
for ( TQValueList<KNArticleFilter*>::Iterator it = mFilterList.begin(); it != mFilterList.end(); ++it )
activeFilters << (*it)->id();
int newId = 1;
- while ( activeFilters.contains( newId ) > 0 )
+ while ( activeFilters.tqcontains( newId ) > 0 )
newId++;
f->setId( newId );
}
diff --git a/knode/knfolder.cpp b/knode/knfolder.cpp
index 01855d5b..81f4f01a 100644
--- a/knode/knfolder.cpp
+++ b/knode/knfolder.cpp
@@ -193,7 +193,7 @@ bool KNFolder::loadHdrs()
int pos1=0, pos2=0, cnt=0, byteCount;
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Loading folder..."));
+ knGlobals.seStatusMsg(i18n(" Loading folder..."));
knGlobals.top->secureProcessEvents();
while(!i_ndexFile.atEnd()) {
@@ -284,7 +284,7 @@ bool KNFolder::loadHdrs()
clear();
closeFiles();
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
return false;
}
@@ -297,7 +297,7 @@ bool KNFolder::loadHdrs()
c_ount=cnt;
updateListItem();
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
return true;
diff --git a/knode/knfoldermanager.cpp b/knode/knfoldermanager.cpp
index 7e3465bf..e857f4bb 100644
--- a/knode/knfoldermanager.cpp
+++ b/knode/knfoldermanager.cpp
@@ -294,7 +294,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
if (file) {
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Importing articles..."));
+ knGlobals.seStatusMsg(i18n(" Importing articles..."));
knGlobals.top->secureProcessEvents();
if (!file->atEnd()) { // search for the first article...
@@ -360,13 +360,13 @@ void KNFolderManager::importFromMBox(KNFolder *f)
}
}
- knGlobals.setStatusMsg(i18n(" Storing articles..."));
+ knGlobals.seStatusMsg(i18n(" Storing articles..."));
knGlobals.top->secureProcessEvents();
if (!list.isEmpty())
knGlobals.articleManager()->moveIntoFolder(list, f);
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
}
@@ -391,7 +391,7 @@ void KNFolderManager::exportToMBox(KNFolder *f)
if (file) {
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Exporting articles..."));
+ knGlobals.seStatusMsg(i18n(" Exporting articles..."));
knGlobals.top->secureProcessEvents();
TQTextStream ts(file);
@@ -415,7 +415,7 @@ void KNFolderManager::exportToMBox(KNFolder *f)
knGlobals.top->secureProcessEvents();
}
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
}
}
diff --git a/knode/knglobals.cpp b/knode/knglobals.cpp
index eaf026e8..7a6f0c22 100644
--- a/knode/knglobals.cpp
+++ b/knode/knglobals.cpp
@@ -134,8 +134,8 @@ KNMemoryManager* KNGlobals::memoryManager()
}
-void KNGlobals::setStatusMsg(const TQString &text, int id)
+void KNGlobals::seStatusMsg(const TQString &text, int id)
{
if(top)
- top->setStatusMsg(text, id);
+ top->seStatusMsg(text, id);
}
diff --git a/knode/kngroup.cpp b/knode/kngroup.cpp
index e55bee10..3584e744 100644
--- a/knode/kngroup.cpp
+++ b/knode/kngroup.cpp
@@ -71,7 +71,7 @@ void KNGroup::updateListItem()
if(!l_istItem) return;
l_istItem->setTotalCount( c_ount );
l_istItem->setUnreadCount( c_ount - r_eadCount - i_gnoreCount );
- l_istItem->repaint();
+ l_istItem->tqrepaint();
}
@@ -133,7 +133,7 @@ void KNGroup::saveInfo()
info.writeEntry("dynDataFormat", d_ynDataFormat);
info.writeEntry("name", n_ame);
info.writeEntry("useCharset", u_seCharset);
- info.writeEntry("defaultChSet", TQString::fromLatin1(d_efaultChSet));
+ info.writeEntry("defaultChSet", TQString::tqfromLatin1(d_efaultChSet));
switch (s_tatus) {
case unknown: info.writeEntry("status","unknown");
break;
@@ -492,7 +492,7 @@ void KNGroup::insortNewHeaders(TQStrList *hdrs, TQStrList *hdrfmt, KNProtocolCli
}
// now we build the threads
- syncSearchIndex(); // recreate the msgId-index so it contains the appended headers
+ syncSearchIndex(); // recreate the msgId-index so it tqcontains the appended headers
buildThreads(added_cnt, client);
updateThreadInfo();
@@ -904,7 +904,7 @@ void KNGroup::scoreArticles(bool onlynew)
kdDebug(5003) << "scoring " << newCount() << " articles" << endl;
kdDebug(5003) << "(total " << length() << " article in group)" << endl;
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Scoring..."));
+ knGlobals.seStatusMsg(i18n(" Scoring..."));
int defScore;
KScoringManager *sm = knGlobals.scoringManager();
@@ -936,7 +936,7 @@ void KNGroup::scoreArticles(bool onlynew)
incReadCount();
}
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
//kdDebug(5003) << KNScorableArticle::notifyC->collection() << endl;
@@ -951,7 +951,7 @@ void KNGroup::reorganize()
kdDebug(5003) << "KNGroup::reorganize()" << endl;
knGlobals.top->setCursorBusy(true);
- knGlobals.setStatusMsg(i18n(" Reorganizing headers..."));
+ knGlobals.seStatusMsg(i18n(" Reorganizing headers..."));
for(int idx=0; idx<length(); idx++) {
KNRemoteArticle *a = at(idx);
@@ -964,8 +964,8 @@ void KNGroup::reorganize()
buildThreads(length());
saveStaticData(length(), true);
saveDynamicData(length(), true);
- knGlobals.top->headerView()->repaint();
- knGlobals.setStatusMsg(TQString::null);
+ knGlobals.top->headerView()->tqrepaint();
+ knGlobals.seStatusMsg(TQString::null);
knGlobals.top->setCursorBusy(false);
}
diff --git a/knode/kngroup.h b/knode/kngroup.h
index fef5c6d6..76a9d0dd 100644
--- a/knode/kngroup.h
+++ b/knode/kngroup.h
@@ -124,7 +124,7 @@ class KNGroup : public KNArticleCollection , public KNJobItem {
KNConfig::Identity* identity()const { return i_dentity; }
void setIdentity(KNConfig::Identity *i) { i_dentity=i; }
Status status()const { return s_tatus; }
- void setStatus(Status s) { s_tatus=s; }
+ void seStatus(Status s) { s_tatus=s; }
void showProperties();
// cleanup configuration
diff --git a/knode/kngroupbrowser.cpp b/knode/kngroupbrowser.cpp
index be91593a..d8e3f835 100644
--- a/knode/kngroupbrowser.cpp
+++ b/knode/kngroupbrowser.cpp
@@ -92,7 +92,7 @@ KNGroupBrowser::KNGroupBrowser(TQWidget *parent, const TQString &caption, KNNntp
connect(groupView, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
this, TQT_SLOT(slotItemDoubleClicked(TQListViewItem*)));
- //layout
+ //tqlayout
TQGridLayout *topL=new TQGridLayout(page,3,1,0,5);
TQHBoxLayout *filterL=new TQHBoxLayout(10);
TQVBoxLayout *arrL=new TQVBoxLayout(10);
@@ -316,7 +316,7 @@ void KNGroupBrowser::slotFilter(const TQString &txt)
bool notCheckNew = !newCB->isChecked();
bool notCheckStr = (filtertxt.isEmpty());
- bool isRegexp = filtertxt.contains(TQRegExp("[^a-z0-9\\-\\+.]"));
+ bool isRegexp = filtertxt.tqcontains(TQRegExp("[^a-z0-9\\-\\+.]"));
bool doIncrementalUpdate = (!isRegexp && incrementalFilter && (filtertxt.left(lastFilter.length())==lastFilter));
@@ -411,7 +411,7 @@ KNGroupBrowser::CheckItem::CheckItem(TQListView *v, const KNGroupInfo &gi, KNGro
TQString des(gi.description);
if (gi.status == KNGroup::moderated) {
setText(0,gi.name+" (m)");
- if (!des.upper().contains(i18n("moderated").upper()))
+ if (!des.upper().tqcontains(i18n("moderated").upper()))
des+=i18n(" (moderated)");
}
setText(1,des);
@@ -424,7 +424,7 @@ KNGroupBrowser::CheckItem::CheckItem(TQListViewItem *i, const KNGroupInfo &gi, K
TQString des(gi.description);
if (gi.status == KNGroup::moderated) {
setText(0,gi.name+" (m)");
- if (!des.upper().contains(i18n("moderated").upper()))
+ if (!des.upper().tqcontains(i18n("moderated").upper()))
des+=i18n(" (moderated)");
}
setText(1,des);
diff --git a/knode/kngroupdialog.cpp b/knode/kngroupdialog.cpp
index 64deea4f..bff6dfd5 100644
--- a/knode/kngroupdialog.cpp
+++ b/knode/kngroupdialog.cpp
@@ -300,7 +300,7 @@ void KNGroupDialog::slotUser2()
topL->addMultiCellWidget(takeCustom, 2, 2, 0, 1);
KDatePicker *dateSel = new KDatePicker(btnGrp, lastDate);
- dateSel->setMinimumSize(dateSel->sizeHint());
+ dateSel->setMinimumSize(dateSel->tqsizeHint());
topL->addWidget(dateSel, 3, 1, Qt::AlignLeft);
connect(takeCustom, TQT_SIGNAL(toggled(bool)), dateSel, TQT_SLOT(setEnabled(bool)));
@@ -314,7 +314,7 @@ void KNGroupDialog::slotUser2()
if (dlg->exec()) {
if (takeCustom->isChecked())
lastDate = dateSel->date();
- a_ccount->setLastNewFetch(TQDate::currentDate());
+ a_ccount->setLastNewFetch(TQDate::tqcurrentDate());
leftLabel->setText(i18n("Checking for new groups..."));
enableButton(User1,false);
enableButton(User2,false);
diff --git a/knode/kngroupmanager.cpp b/knode/kngroupmanager.cpp
index 429b93bc..2bece357 100644
--- a/knode/kngroupmanager.cpp
+++ b/knode/kngroupmanager.cpp
@@ -139,7 +139,7 @@ bool KNGroupListData::readIn(KNProtocolClient *client)
}
}
- if (subscribed.contains(name)) {
+ if (subscribed.tqcontains(name)) {
subscribed.remove(name); // group names are unique, we wont find it again anyway...
sub = true;
} else
@@ -435,7 +435,7 @@ void KNGroupManager::subscribeGroup(const KNGroupInfo *gi, KNNntpAccount *a)
grp=new KNGroup(a);
grp->setGroupname(gi->name);
grp->setDescription(gi->description);
- grp->setStatus(gi->status);
+ grp->seStatus(gi->status);
grp->saveInfo();
mGroupList.append( grp );
emit groupAdded(grp);
@@ -596,7 +596,7 @@ void KNGroupManager::processJob(KNJobData *j)
for ( KNGroupInfo* inf = d->groups->first(); inf; inf = d->groups->next() )
if ( inf->name == (*it)->groupname() ) {
(*it)->setDescription( inf->description );
- (*it)->setStatus( inf->status );
+ (*it)->seStatus( inf->status );
break;
}
}
diff --git a/knode/kngroupmanager.h b/knode/kngroupmanager.h
index f4240712..f93b5704 100644
--- a/knode/kngroupmanager.h
+++ b/knode/kngroupmanager.h
@@ -31,7 +31,7 @@ class KNCleanUp;
//=================================================================================
/** helper classes for the group selection dialog
- contains info about a newsgroup (name, description) */
+ tqcontains info about a newsgroup (name, description) */
class KNGroupInfo {
diff --git a/knode/kngrouppropdlg.cpp b/knode/kngrouppropdlg.cpp
index 3ad2fee7..4983b428 100644
--- a/knode/kngrouppropdlg.cpp
+++ b/knode/kngrouppropdlg.cpp
@@ -152,7 +152,7 @@ KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *parent, const char *nam
cleanupLayout->addWidget( mCleanupWidget );
cleanupLayout->addStretch( 1 );
- KNHelper::restoreWindowSize("groupPropDLG", this, sizeHint());
+ KNHelper::restoreWindowSize("groupPropDLG", this, tqsizeHint());
}
diff --git a/knode/kngroupselectdialog.cpp b/knode/kngroupselectdialog.cpp
index 2cb02401..199abce8 100644
--- a/knode/kngroupselectdialog.cpp
+++ b/knode/kngroupselectdialog.cpp
@@ -104,7 +104,7 @@ TQString KNGroupSelectDialog::selectedGroups()const
}
if (moderated && (count>=2)) // warn the user
- KMessageBox::information(parentWidget(),i18n("You are crossposting to a moderated newsgroup.\nPlease be aware that your article will not appear in any group\nuntil it has been approved by the moderators of the moderated group."),
+ KMessageBox::information(tqparentWidget(),i18n("You are crossposting to a moderated newsgroup.\nPlease be aware that your article will not appear in any group\nuntil it has been approved by the moderators of the moderated group."),
TQString::null,"crosspostModeratedWarning");
return ret;
diff --git a/knode/knhdrviewitem.cpp b/knode/knhdrviewitem.cpp
index e547b11d..c7f500a0 100644
--- a/knode/knhdrviewitem.cpp
+++ b/knode/knhdrviewitem.cpp
@@ -114,7 +114,7 @@ int KNHdrViewItem::compare( TQListViewItem *i, int col, bool ) const
}
-void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
+void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
{
int xText = 0, xPM = 3, yPM = 0;
TQColor base;
@@ -172,7 +172,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
else
mShowToolTip[column] = false;
- p->drawText( xText, 0, width - xText - 5, height(), alignment | AlignVCenter, t );
+ p->drawText( xText, 0, width - xText - 5, height(), tqalignment | AlignVCenter, t );
if (cntWidth) {
TQFont orig = p->font();
p->setFont( f2 );
@@ -183,7 +183,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
pen.setColor( cg.link() );
}
p->setPen( pen );
- p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), alignment | AlignVCenter, t2 );
+ p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), tqalignment | AlignVCenter, t2 );
}
}
}
diff --git a/knode/knhdrviewitem.h b/knode/knhdrviewitem.h
index 476c6d53..163a4507 100644
--- a/knode/knhdrviewitem.h
+++ b/knode/knhdrviewitem.h
@@ -33,7 +33,7 @@ class KNHdrViewItem : public KListViewItem {
virtual int compare(TQListViewItem *i, int col, bool ascending) const;
- void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
int width(const TQFontMetrics &fm, const TQListView *lv, int column);
virtual TQString text( int col ) const;
diff --git a/knode/knjobdata.cpp b/knode/knjobdata.cpp
index 5d46c29d..a0def5d1 100644
--- a/knode/knjobdata.cpp
+++ b/knode/knjobdata.cpp
@@ -95,7 +95,7 @@ void KNJobData::cancel()
mJob = 0;
}
if ( mProgressItem ) {
- mProgressItem->setStatus( "Canceled" );
+ mProgressItem->seStatus( "Canceled" );
mProgressItem->setComplete();
mProgressItem = 0;
}
@@ -140,7 +140,7 @@ void KNJobData::slotJobPercent( KIO::Job*, unsigned long percent )
void KNJobData::slotJobInfoMessage( KIO::Job*, const TQString &msg )
{
kdDebug(5003) << k_funcinfo << "Status: " << msg << endl;
- setStatus( msg );
+ seStatus( msg );
}
diff --git a/knode/knjobdata.h b/knode/knjobdata.h
index 35b54e93..14b1bca7 100644
--- a/knode/knjobdata.h
+++ b/knode/knjobdata.h
@@ -114,7 +114,7 @@ class KNJobData : public QObject
void createProgressItem();
// safe forwards to the progress item
- void setStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->setStatus( msg ); }
+ void seStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->seStatus( msg ); }
void setProgress( unsigned int progress ) { if ( mProgressItem ) mProgressItem->setProgress( progress ); }
void setComplete() { if ( mProgressItem ) { mProgressItem->setComplete(); mProgressItem = 0; } }
diff --git a/knode/knmainwidget.cpp b/knode/knmainwidget.cpp
index 0697a919..6686d3f0 100644
--- a/knode/knmainwidget.cpp
+++ b/knode/knmainwidget.cpp
@@ -34,7 +34,7 @@
#include "broadcaststatus.h"
#include "krsqueezedtextlabel.h"
#include "recentaddresses.h"
-using KPIM::BroadcastStatus;
+using KPIM::BroadcasStatus;
using KRecentAddress::RecentAddresses;
//GUI
@@ -85,7 +85,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
//-------------------------------- <GUI> ------------------------------------
TQAccel *accel = new TQAccel( this );
- initStatusBar();
+ iniStatusBar();
//setup splitter behavior
manager()->setSplitterHighResolution(true);
@@ -253,7 +253,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
c_olView->setFocus();
- setStatusMsg();
+ seStatusMsg();
if( firstStart() ) { // open the config dialog on the first start
show(); // the settings dialog must appear in front of the main window!
@@ -302,35 +302,35 @@ KNMainWidget::~KNMainWidget()
delete a_rtDock;
}
-void KNMainWidget::initStatusBar()
+void KNMainWidget::iniStatusBar()
{
//statusbar
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *sb = mainWin ? mainWin->statusBar() : 0;
s_tatusFilter = new KRSqueezedTextLabel( TQString::null, sb );
- s_tatusFilter->setAlignment( AlignLeft | AlignVCenter );
+ s_tatusFilter->tqsetAlignment( AlignLeft | AlignVCenter );
s_tatusGroup = new KRSqueezedTextLabel( TQString::null, sb );
- s_tatusGroup->setAlignment( AlignLeft | AlignVCenter );
+ s_tatusGroup->tqsetAlignment( AlignLeft | AlignVCenter );
}
//================================== GUI =================================
-void KNMainWidget::setStatusMsg(const TQString& text, int id)
+void KNMainWidget::seStatusMsg(const TQString& text, int id)
{
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
if ( !bar )
return;
bar->clear();
if (text.isEmpty() && (id==SB_MAIN)) {
if (knGlobals.netAccess()->currentMsg().isEmpty())
- BroadcastStatus::instance()->setStatusMsg(i18n(" Ready"));
+ BroadcasStatus::instance()->seStatusMsg(i18n(" Ready"));
else
- BroadcastStatus::instance()->setStatusMsg(knGlobals.netAccess()->currentMsg());
+ BroadcasStatus::instance()->seStatusMsg(knGlobals.netAccess()->currentMsg());
} else {
switch(id) {
case SB_MAIN:
- BroadcastStatus::instance()->setStatusMsg(text); break;
+ BroadcasStatus::instance()->seStatusMsg(text); break;
case SB_GROUP:
s_tatusGroup->setText(text); break;
case SB_FILTER:
@@ -340,9 +340,9 @@ void KNMainWidget::setStatusMsg(const TQString& text, int id)
}
-void KNMainWidget::setStatusHelpMsg(const TQString& text)
+void KNMainWidget::seStatusHelpMsg(const TQString& text)
{
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
if ( bar )
bar->message(text, 2000);
@@ -375,7 +375,7 @@ void KNMainWidget::setCursorBusy(bool b)
void KNMainWidget::blockUI(bool b)
{
b_lockui = b;
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KMenuBar *mbar = mainWin ? mainWin->menuBar() : 0;
if ( mbar )
mbar->setEnabled(!b);
@@ -394,7 +394,7 @@ void KNMainWidget::blockUI(bool b)
void KNMainWidget::disableAccels(bool b)
{
a_ccel->setEnabled(!b);
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KAccel *naccel = mainWin ? mainWin->accel() : 0;
if ( naccel )
naccel->setEnabled(!b);
@@ -409,7 +409,7 @@ void KNMainWidget::disableAccels(bool b)
void KNMainWidget::secureProcessEvents()
{
b_lockui = true;
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KMenuBar *mbar = mainWin ? mainWin->menuBar() : 0;
if ( mbar )
mbar->setEnabled(false);
@@ -431,7 +431,7 @@ void KNMainWidget::secureProcessEvents()
}
-TQSize KNMainWidget::sizeHint() const
+TQSize KNMainWidget::tqsizeHint() const
{
return TQSize(759,478); // default optimized for 800x600
}
@@ -484,7 +484,7 @@ void KNMainWidget::openURL(const KURL &url)
}
if (acc) {
- bool isMID=(url.url().contains('@')==1);
+ bool isMID=(url.url().tqcontains('@')==1);
if (!isMID) {
TQString groupname=url.path(-1);
@@ -903,7 +903,7 @@ bool KNMainWidget::queryClose()
void KNMainWidget::showEvent(TQShowEvent *)
{
- slotCheckDockWidgetStatus();
+ slotCheckDockWidgeStatus();
}
@@ -1301,7 +1301,7 @@ void KNMainWidget::slotNetworkActive(bool b)
}
-void KNMainWidget::slotCheckDockWidgetStatus()
+void KNMainWidget::slotCheckDockWidgeStatus()
{
a_ctToggleGroupView->setChecked(c_olDock->isVisible());
a_ctToggleArticleViewer->setChecked(a_rtDock->isVisible());
@@ -1966,7 +1966,7 @@ void KNMainWidget::slotFetchArticleWithID()
void KNMainWidget::slotToggleGroupView()
{
c_olDock->changeHideShowState();
- slotCheckDockWidgetStatus();
+ slotCheckDockWidgeStatus();
}
@@ -1977,19 +1977,19 @@ void KNMainWidget::slotToggleHeaderView()
if ( !h_drDock->isDockBackPossible() ) {
h_drDock->manualDock( a_rtDock, KDockWidget::DockTop );
h_drDock->makeDockVisible();
- slotCheckDockWidgetStatus();
+ slotCheckDockWidgeStatus();
return;
}
h_drDock->changeHideShowState();
- slotCheckDockWidgetStatus();
+ slotCheckDockWidgeStatus();
}
void KNMainWidget::slotToggleArticleViewer()
{
a_rtDock->changeHideShowState();
- slotCheckDockWidgetStatus();
+ slotCheckDockWidgeStatus();
}
void KNMainWidget::slotToggleQuickSearch()
diff --git a/knode/knmainwidget.h b/knode/knmainwidget.h
index 5a02790c..4717e333 100644
--- a/knode/knmainwidget.h
+++ b/knode/knmainwidget.h
@@ -72,8 +72,8 @@ public:
void prepareShutdown();
//GUI
- void setStatusMsg(const TQString& = TQString::null, int id=SB_MAIN);
- void setStatusHelpMsg(const TQString& text);
+ void seStatusMsg(const TQString& = TQString::null, int id=SB_MAIN);
+ void seStatusHelpMsg(const TQString& text);
void updateCaption();
void setCursorBusy(bool b=true);
void blockUI(bool b=true);
@@ -82,7 +82,7 @@ public:
void secureProcessEvents();
/** useful default value */
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/** handle URL given as command-line argument */
void openURL(const KURL &url);
@@ -163,7 +163,7 @@ protected:
KXMLGUIFactory *factory() const;
void initActions();
- void initStatusBar();
+ void iniStatusBar();
/** checks if run for the first time, sets some global defaults (email configuration) */
bool firstStart();
@@ -229,7 +229,7 @@ protected slots:
void slotNetworkActive(bool b);
//dock widget slots
- void slotCheckDockWidgetStatus();
+ void slotCheckDockWidgeStatus();
void slotGroupDockHidden();
void slotHeaderDockHidden();
void slotArticleDockHidden();
diff --git a/knode/knmemorymanager.cpp b/knode/knmemorymanager.cpp
index 37a63928..365e9f8c 100644
--- a/knode/knmemorymanager.cpp
+++ b/knode/knmemorymanager.cpp
@@ -162,7 +162,7 @@ void KNMemoryManager::checkMemoryUsageCollections()
for ( TQValueList<CollectionItem*>::Iterator it = tempList.begin(); it != tempList.end(); ) {
if ( c_ollCacheSize <= maxSize )
break;
- // unloadHeaders() will remove the cache entry and thus invalidate the iterator!
+ // unloadHeaders() will remove the cache entry and thus tqinvalidate the iterator!
c = (*it)->col;
++it;
@@ -191,7 +191,7 @@ void KNMemoryManager::checkMemoryUsageArticles()
for ( TQValueList<ArticleItem*>::Iterator it = mArtList.begin(); it != mArtList.end(); ) {
if ( a_rtCacheSize <= maxSize )
break;
- // unloadArticle() will remove the cache entry and thus invalidate the iterator!
+ // unloadArticle() will remove the cache entry and thus tqinvalidate the iterator!
KNArticle *art = (*it)->art;
++it;
knGlobals.articleManager()->unloadArticle( art, false ); // *try* to unload
diff --git a/knode/knnetaccess.cpp b/knode/knnetaccess.cpp
index 7fc6fd37..016a39ee 100644
--- a/knode/knnetaccess.cpp
+++ b/knode/knnetaccess.cpp
@@ -102,7 +102,7 @@ void KNNetAccess::addJob(KNJobData *job)
if ( !job->account()->readyForLogin() ) {
mWalletQueue.append( job );
knGlobals.accountManager()->loadPasswordsAsync();
- job->setStatus( i18n( "Waiting for KWallet..." ) );
+ job->seStatus( i18n( "Waiting for KWallet..." ) );
return;
}
@@ -332,7 +332,7 @@ void KNNetAccess::threadDoneNntp()
currentNntpJob = 0L;
currMsg = TQString::null;
- knGlobals.setStatusMsg();
+ knGlobals.seStatusMsg();
tmp->setComplete();
tmp->notifyConsumer();
@@ -359,7 +359,7 @@ void KNNetAccess::threadDoneSmtp()
currentSmtpJob = 0L;
if (!currentNntpJob) {
currMsg = TQString::null;
- knGlobals.setStatusMsg();
+ knGlobals.seStatusMsg();
}
tmp->setComplete();
@@ -398,53 +398,53 @@ void KNNetAccess::slotThreadSignal(int i)
break;
case KNProtocolClient::TSconnect:
currMsg = i18n(" Connecting to server...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSloadGrouplist:
currMsg = i18n(" Loading group list from disk...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSwriteGrouplist:
currMsg = i18n(" Writing group list to disk...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSdownloadGrouplist:
currMsg = i18n(" Downloading group list...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNewGroups:
currMsg = i18n(" Looking for new groups...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSdownloadDesc:
currMsg = i18n(" Downloading group descriptions...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNew:
currMsg = i18n(" Downloading new headers...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSsortNew:
currMsg = i18n(" Sorting...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSdownloadArticle:
currMsg = i18n(" Downloading article...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSsendArticle:
currMsg = i18n(" Sending article...");
- knGlobals.setStatusMsg(currMsg);
- currentNntpJob->setStatus(currMsg);
+ knGlobals.seStatusMsg(currMsg);
+ currentNntpJob->seStatus(currMsg);
break;
case KNProtocolClient::TSjobStarted:
currentNntpJob->setProgress(0);
@@ -477,7 +477,7 @@ void KNNetAccess::slotPasswordsChanged()
{
TQValueList<KNJobData*>::ConstIterator it;
for ( it = mWalletQueue.begin(); it != mWalletQueue.end(); ++it ) {
- (*it)->setStatus( i18n("Waiting...") );
+ (*it)->seStatus( i18n("Waiting...") );
if ( (*it)->type() == KNJobData::JTmail )
smtpJobQueue.append( (*it) );
else
diff --git a/knode/knnntpaccount.cpp b/knode/knnntpaccount.cpp
index ba1657c0..1887baae 100644
--- a/knode/knnntpaccount.cpp
+++ b/knode/knnntpaccount.cpp
@@ -75,7 +75,7 @@ void KNNntpAccountIntervalChecking::slotCheckNews()
KNNntpAccount::KNNntpAccount()
: KNCollection(0), KNServerInfo(), i_dentity(0), f_etchDescriptions(true), w_asOpen(false), i_ntervalChecking(false), c_heckInterval(10)
{
- l_astNewFetch = TQDate::currentDate();
+ l_astNewFetch = TQDate::tqcurrentDate();
a_ccountIntervalChecking = new KNNntpAccountIntervalChecking(this);
mCleanupConf = new KNConfig::Cleanup( false );
}
diff --git a/knode/knnntpclient.cpp b/knode/knnntpclient.cpp
index 47942d6b..dd4f28fe 100644
--- a/knode/knnntpclient.cpp
+++ b/knode/knnntpclient.cpp
@@ -115,7 +115,7 @@ void KNNntpClient::doFetchGroups()
name = TQString::fromUtf8(line);
- if (target->subscribed.contains(name)) {
+ if (target->subscribed.tqcontains(name)) {
target->subscribed.remove(name); // group names are unique, we wont find it again anyway...
subscribed = true;
} else
diff --git a/knode/knode.cpp b/knode/knode.cpp
index c2d7ee7f..d3df5b74 100644
--- a/knode/knode.cpp
+++ b/knode/knode.cpp
@@ -55,7 +55,7 @@ KNMainWindow::KNMainWindow( TQWidget* pWidget )
TQT_SLOT( setCaption(const TQString&)) );
setCentralWidget( m_mainWidget );
setupStatusBar();
- connect( KPIM::BroadcastStatus::instance(), TQT_SIGNAL(statusMsg(const TQString&)),
+ connect( KPIM::BroadcasStatus::instance(), TQT_SIGNAL(statusMsg(const TQString&)),
this, TQT_SLOT(slotShowStatusMsg(const TQString& )) );
createGUI( "knodeui.rc" );
knGlobals.instance = 0;
@@ -109,7 +109,7 @@ void KNMainWindow::setupStatusBar()
statusBar()->addWidget( mLittleProgress, 0 , true );
mStatusMsgLabel = new KRSqueezedTextLabel( TQString::null, statusBar() );
- mStatusMsgLabel->setAlignment( AlignLeft | AlignVCenter );
+ mStatusMsgLabel->tqsetAlignment( AlignLeft | AlignVCenter );
statusBar()->addWidget( mStatusMsgLabel, 2 );
statusBar()->addWidget(m_mainWidget->statusBarLabelFilter(), 2);
statusBar()->addWidget(m_mainWidget->statusBarLabelGroup(), 3);
diff --git a/knode/knode.h b/knode/knode.h
index d628df1b..2c350c62 100644
--- a/knode/knode.h
+++ b/knode/knode.h
@@ -46,7 +46,7 @@ class KNMainWindow : public KMainWindow
Q_OBJECT
public:
- KNMainWindow( TQWidget* parentWidget=0 );
+ KNMainWindow( TQWidget* tqparentWidget=0 );
~KNMainWindow();
void openURL( const KURL& );
KNMainWidget *mainWidget() { return m_mainWidget; }
diff --git a/knode/knode_part.cpp b/knode/knode_part.cpp
index 52b3e4dd..3e54361a 100644
--- a/knode/knode_part.cpp
+++ b/knode/knode_part.cpp
@@ -47,10 +47,10 @@
typedef KParts::GenericFactory< KNodePart > KNodeFactory;
K_EXPORT_COMPONENT_FACTORY( libknodepart, KNodeFactory )
-KNodePart::KNodePart(TQWidget *parentWidget, const char *widgetName,
+KNodePart::KNodePart(TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name, const TQStringList &)
: KParts::ReadOnlyPart(parent, name),
- mParentWidget( parentWidget )
+ mParentWidget( tqparentWidget )
{
kdDebug(5003) << "KNodePart()" << endl;
kdDebug(5003) << " InstanceName: " << kapp->instanceName() << endl;
@@ -67,7 +67,7 @@ KNodePart::KNodePart(TQWidget *parentWidget, const char *widgetName,
knGlobals.instance = KNodeFactory::instance();
// create a canvas to insert our widget
- TQWidget *canvas = new TQWidget(parentWidget, widgetName);
+ TQWidget *canvas = new TQWidget(tqparentWidget, widgetName);
canvas->setFocusPolicy(TQWidget::ClickFocus);
setWidget(canvas);
@@ -114,7 +114,7 @@ void KNodePart::guiActivateEvent(KParts::GUIActivateEvent *e)
}
-TQWidget* KNodePart::parentWidget() const
+TQWidget* KNodePart::tqparentWidget() const
{
return mParentWidget;
}
diff --git a/knode/knode_part.h b/knode/knode_part.h
index 67e1ae54..1e9a4904 100644
--- a/knode/knode_part.h
+++ b/knode/knode_part.h
@@ -43,11 +43,11 @@ class KNodePart: public KParts::ReadOnlyPart
{
Q_OBJECT
public:
- KNodePart(TQWidget *parentWidget, const char *widgetName,
+ KNodePart(TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name, const TQStringList &);
virtual ~KNodePart();
- TQWidget* parentWidget() const;
+ TQWidget* tqparentWidget() const;
static KAboutData *createAboutData();
diff --git a/knode/knrangefilter.cpp b/knode/knrangefilter.cpp
index ee14c794..a0f01856 100644
--- a/knode/knrangefilter.cpp
+++ b/knode/knrangefilter.cpp
@@ -118,7 +118,7 @@ KNRangeFilterWidget::KNRangeFilterWidget(const TQString& value, int min, int max
op2->insertItem("<=");
des=new TQLabel(value, this);
- des->setAlignment(AlignCenter);
+ des->tqsetAlignment(AlignCenter);
TQGridLayout *topL=new TQGridLayout(this, 2,6, 8,5 );
diff --git a/knode/knsearchdialog.cpp b/knode/knsearchdialog.cpp
index f72afe47..4344cbba 100644
--- a/knode/knsearchdialog.cpp
+++ b/knode/knsearchdialog.cpp
@@ -68,8 +68,8 @@ KNSearchDialog::KNSearchDialog(searchType /*t*/, TQWidget *parent)
f_ilter->setLoaded(true);
f_ilter->setSearchFilter(true);
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("searchDlg", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("searchDlg", this, tqsizeHint());
fcw->setStartFocus();
}
diff --git a/knode/knserverinfo.cpp b/knode/knserverinfo.cpp
index d314a771..0a259815 100644
--- a/knode/knserverinfo.cpp
+++ b/knode/knserverinfo.cpp
@@ -78,9 +78,9 @@ void KNServerInfo::readConf(KConfig *conf)
readPassword();
TQString encStr = conf->readEntry( "encryption", "None" );
- if ( encStr.contains( "SSL", false ) )
+ if ( encStr.tqcontains( "SSL", false ) )
mEncryption = SSL;
- else if ( encStr.contains( "TLS", false ) )
+ else if ( encStr.tqcontains( "TLS", false ) )
mEncryption = TLS;
else
mEncryption = None;
diff --git a/knode/knstringfilter.cpp b/knode/knstringfilter.cpp
index 4f69f7ea..3f866902 100644
--- a/knode/knstringfilter.cpp
+++ b/knode/knstringfilter.cpp
@@ -57,7 +57,7 @@ bool KNStringFilter::doFilter(const TQString &s)
-// replace placeholders
+// tqreplace placeholders
void KNStringFilter::expand(KNGroup *g)
{
KNConfig::Identity *id = (g) ? g->identity() : 0;
@@ -69,15 +69,15 @@ void KNStringFilter::expand(KNGroup *g)
}
expanded = data;
- expanded.replace(TQRegExp("%MYNAME"), id->name());
- expanded.replace(TQRegExp("%MYEMAIL"), id->email());
+ expanded.tqreplace(TQRegExp("%MYNAME"), id->name());
+ expanded.tqreplace(TQRegExp("%MYEMAIL"), id->email());
}
void KNStringFilter::load(KSimpleConfig *conf)
{
- con=conf->readBoolEntry("contains", true);
+ con=conf->readBoolEntry("tqcontains", true);
data=conf->readEntry("Data");
regExp=conf->readBoolEntry("regX", false);
}
@@ -86,7 +86,7 @@ void KNStringFilter::load(KSimpleConfig *conf)
void KNStringFilter::save(KSimpleConfig *conf)
{
- conf->writeEntry("contains", con);
+ conf->writeEntry("tqcontains", con);
conf->writeEntry("Data", data);
conf->writeEntry("regX", regExp);
}
diff --git a/knode/knstringfilter.h b/knode/knstringfilter.h
index ac33c1d6..5720c6a8 100644
--- a/knode/knstringfilter.h
+++ b/knode/knstringfilter.h
@@ -37,7 +37,7 @@ class KNStringFilter {
~KNStringFilter() {}
KNStringFilter& operator=(const KNStringFilter &sf);
- /** replace placeholders */
+ /** tqreplace placeholders */
void expand(KNGroup *g);
void load(KSimpleConfig *conf);
diff --git a/knode/knwidgets.cpp b/knode/knwidgets.cpp
index d75cf9bf..d3f1d7b5 100644
--- a/knode/knwidgets.cpp
+++ b/knode/knwidgets.cpp
@@ -107,10 +107,10 @@ void KNDialogListBox::keyPressEvent(TQKeyEvent *e)
//====================================================================================
-KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *focusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock, const char* name )
+KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock, const char* name )
: KDockWidgetHeaderDrag(parent, dock, name), f_ocus(false)
{
- connect(focusWidget, TQT_SIGNAL(focusChanged(TQFocusEvent*)), TQT_SLOT(slotFocusChanged(TQFocusEvent*)));
+ connect(tqfocusWidget, TQT_SIGNAL(focusChanged(TQFocusEvent*)), TQT_SLOT(slotFocusChanged(TQFocusEvent*)));
}
@@ -141,7 +141,7 @@ void KNDockWidgetHeaderDrag::paintEvent(TQPaintEvent* ev)
TQPainter paint;
paint.begin(&drawBuffer);
- paint.fillRect(drawBuffer.rect(), TQBrush(colorGroup().brush(TQColorGroup::Background)));
+ paint.fillRect(drawBuffer.rect(), TQBrush(tqcolorGroup().brush(TQColorGroup::Background)));
paint.setPen(palette().active().highlight());
paint.drawLine(1, 2, width(), 2);
diff --git a/knode/knwidgets.h b/knode/knwidgets.h
index bb01ba22..d1a19e36 100644
--- a/knode/knwidgets.h
+++ b/knode/knwidgets.h
@@ -71,7 +71,7 @@ class KNDockWidgetHeaderDrag : public KDockWidgetHeaderDrag
Q_OBJECT
public:
- KNDockWidgetHeaderDrag(TQWidget *focusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock,
+ KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock,
const char* name = 0);
virtual ~KNDockWidgetHeaderDrag();
diff --git a/knode/smtpaccountwidget_base.ui b/knode/smtpaccountwidget_base.ui
index 9acad519..f6565365 100644
--- a/knode/smtpaccountwidget_base.ui
+++ b/knode/smtpaccountwidget_base.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SmtpAccountWidgetBase</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -86,7 +86,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -223,7 +223,7 @@
<slot access="protected">useExternalMailerToggled(bool)</slot>
<slot access="protected">loginToggled(bool)</slot>
</slots>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcmodule.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/knode/utilities.cpp b/knode/utilities.cpp
index 67d4e3ba..1e7dcba9 100644
--- a/knode/utilities.cpp
+++ b/knode/utilities.cpp
@@ -167,7 +167,7 @@ TQFile* KNSaveHelper::getFile(const TQString &dialogTitle)
if (url.isLocalFile()) {
if (TQFileInfo(url.path()).exists() &&
(KMessageBox::warningContinueCancel(knGlobals.topWidget,
- i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to replace it?</qt>").arg(url.path()),
+ i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to tqreplace it?</qt>").arg(url.path()),
dialogTitle, i18n("&Replace")) != KMessageBox::Continue)) {
return 0;
}
@@ -274,7 +274,7 @@ int KNHelper::selectDialog(TQWidget *parent, const TQString &caption, const TQSt
TQString s;
for ( TQStringList::ConstIterator it = options.begin(); it != options.end(); ++it ) {
s = (*it);
- s.replace(TQRegExp("&"),""); // remove accelerators
+ s.tqreplace(TQRegExp("&"),""); // remove accelerators
list->insertItem(s);
}
@@ -293,7 +293,7 @@ int KNHelper::selectDialog(TQWidget *parent, const TQString &caption, const TQSt
return ret;
}
-// **** window geometry managing *********************************************
+// **** window tqgeometry managing *********************************************
void KNHelper::saveWindowSize(const TQString &name, const TQSize &s)
{
@@ -427,7 +427,7 @@ TQString KNHelper::rewrapStringList(TQStringList text, int wrapAt, TQChar quoteC
thisLine = thisLine.stripWhiteSpace();
if(!leftover.isEmpty()) { // don't break paragraphs, tables and quote levels
- if(thisLine.isEmpty() || (thisPrefix!=lastPrefix) || thisLine.contains(" ") || thisLine.contains('\t'))
+ if(thisLine.isEmpty() || (thisPrefix!=lastPrefix) || thisLine.tqcontains(" ") || thisLine.tqcontains('\t'))
appendTextWPrefix(quoted, leftover, wrapAt, lastPrefix);
else
thisLine.prepend(leftover+" ");
diff --git a/knode/articlewidget.cpp b/knode/articlewidget.cpp
index 357a9c00..491d2c9b 100644
--- a/knode/articlewidget.cpp
+++ b/knode/articlewidget.cpp
@@ -374,7 +374,7 @@ void ArticleWidget::displayArticle()
mViewer->view()->ensureVisible( 0, 0 );
if ( !mArticle->hasContent() ) {
- displayErrorMessage( i18n("The article contains no data.") );
+ displayErrorMessage( i18n("The article tqcontains no data.") );
return;
}
@@ -410,12 +410,12 @@ void ArticleWidget::displayArticle()
// signature, we show a nice header:
TQPtrList<Kpgp::Block> pgpBlocks;
TQStrList nonPgpBlocks;
- bool containsPGP = Kpgp::Module::prepareMessageForDecryption( mArticle->body(), pgpBlocks, nonPgpBlocks );
+ bool tqcontainsPGP = Kpgp::Module::prepareMessageForDecryption( mArticle->body(), pgpBlocks, nonPgpBlocks );
mViewer->write ( html );
html = TQString();
- if ( containsPGP ) {
+ if ( tqcontainsPGP ) {
TQPtrListIterator<Kpgp::Block> pbit( pgpBlocks );
TQStrListIterator npbit( nonPgpBlocks );
TQTextCodec *codec;
@@ -490,7 +490,7 @@ void ArticleWidget::displayArticle()
}
}
else {
- if ( !containsPGP ) {
+ if ( !tqcontainsPGP ) {
TQStringList lines;
text->decodedText( lines, true, cfgMgr->readNewsViewer()->removeTrailingNewlines() );
displayBodyBlock( lines );
@@ -527,7 +527,7 @@ void ArticleWidget::displayErrorMessage( const TQString &msg )
mViewer->write( "<b><font size=\"+1\" color=\"red\">" );
mViewer->write( i18n("An error occurred.") );
mViewer->write( "</font></b><hr/><br/>" );
- mViewer->write( errMsg.replace( "\n", "<br/>" ) );
+ mViewer->write( errMsg.tqreplace( "\n", "<br/>" ) );
mViewer->write( "</body></html>");
mViewer->end();
@@ -610,7 +610,7 @@ void ArticleWidget::displayHeader()
headerHtml += toHtmlString( KGlobal::locale()->formatDateTime(date->qdt(), false, true), None );
} else if ( hb->is("Newsgroups") ) {
TQString groups = hb->asUnicodeString();
- groups.replace( ',', ", " );
+ groups.tqreplace( ',', ", " );
headerHtml += toHtmlString( groups, ParseURL );
} else
headerHtml += toHtmlString( hb->asUnicodeString(), ParseURL );
@@ -635,7 +635,7 @@ void ArticleWidget::displayHeader()
TQString xface = "";
if ( !xfhead.isEmpty() ) {
KPIM::KXFace xf;
- xface = TQString::fromLatin1( "<div class=\"senderpic\"><img src=\"%1\" width=\"48\" height=\"48\"/></div>" )
+ xface = TQString::tqfromLatin1( "<div class=\"senderpic\"><img src=\"%1\" width=\"48\" height=\"48\"/></div>" )
.arg( imgToDataUrl( xf.toImage( xfhead ), "PNG" ) );
}
@@ -663,7 +663,7 @@ void ArticleWidget::displayHeader()
html += TQString( "<b>%1</b>" ).arg( i18n("References:") );
while ( i <= refCnt ) {
- html += " <a href=\"news:" + TQString::fromLatin1( id ) + "\">" + TQString::number( i ) + "</a>";
+ html += " <a href=\"news:" + TQString::tqfromLatin1( id ) + "\">" + TQString::number( i ) + "</a>";
id = refs->next();
id = id.mid( 1, id.length() - 2 ); // remove <>
i++;
@@ -836,9 +836,9 @@ void ArticleWidget::displayAttachment( KMime::Content *att, int partNum )
TQString label = ct->name();
if ( label.isEmpty() )
label = i18n("unnamed" );
- // if label consists of only whitespace replace them by underscores
- if ( (uint)label.contains( ' ' ) == label.length() )
- label.replace( TQRegExp( " ", true, true ), "_" );
+ // if label consists of only whitespace tqreplace them by underscores
+ if ( (uint)label.tqcontains( ' ' ) == label.length() )
+ label.tqreplace( TQRegExp( " ", true, true ), "_" );
label = toHtmlString( label, None );
// attachment comment
@@ -915,7 +915,7 @@ TQString ArticleWidget::imgToDataUrl( const TQImage &image, const char* fmt )
TQBuffer buffer( ba );
buffer.open( IO_WriteOnly );
image.save( &buffer, fmt );
- return TQString::fromLatin1("data:image/%1;base64,%2")
+ return TQString::tqfromLatin1("data:image/%1;base64,%2")
.arg( fmt, KCodecs::base64Encode( ba ) );
}
@@ -964,7 +964,7 @@ void ArticleWidget::updateContents()
else
clear();
// restore scrollbar position
- mViewer->view()->setContentsPos( 0, qRound( mViewer->view()->contentsHeight() * savedPosition ) );
+ mViewer->view()->setContentsPos( 0, tqRound( mViewer->view()->contentsHeight() * savedPosition ) );
}
@@ -1158,7 +1158,7 @@ void ArticleWidget::slotURLClicked( const KURL &url, bool forceOpen)
int partNum = 0;
if ( url.protocol() == "file" || url.protocol() == "part" ) {
if ( url.protocol() == "file" ) {
- if ( !mAttachementMap.contains( url.path() ) )
+ if ( !mAttachementMap.tqcontains( url.path() ) )
return;
partNum = mAttachementMap[url.path()];
}
@@ -1167,7 +1167,7 @@ void ArticleWidget::slotURLClicked( const KURL &url, bool forceOpen)
KMime::Content *c = mAttachments.at( partNum );
if ( !c )
return;
// TODO: replace with message box as done in KMail
KNConfigManager *cfgMgr = knGlobals.configManager();
if ( forceOpen || cfgMgr->readNewsViewer()->openAttachmentsOnClick() )
knGlobals.articleManager()->openContent( c );
@@ -1240,7 +1240,7 @@ void ArticleWidget::slotSelectAll()
void ArticleWidget::slotFind()
{
- mViewer->findText();
+ mViewer->tqfindText();
}
@@ -1416,7 +1416,7 @@ void ArticleWidget::slotAddBookmark()
{
if ( mCurrentURL.isEmpty() )
return;
- TQString filename = locateLocal( "data", TQString::fromLatin1("konqueror/bookmarks.xml") );
+ TQString filename = locateLocal( "data", TQString::tqfromLatin1("konqueror/bookmarks.xml") );
KBookmarkManager *bookManager = KBookmarkManager::managerForFile( filename, false );
KBookmarkGroup group = bookManager->root();
group.addBookmark( bookManager, mCurrentURL.url(), mCurrentURL );
@@ -1444,7 +1444,7 @@ void ArticleWidget::slotSaveAttachment()
return;
int partNum = 0;
if ( mCurrentURL.protocol() == "file" ) {
- if ( !mAttachementMap.contains( mCurrentURL.path() ) )
+ if ( !mAttachementMap.tqcontains( mCurrentURL.path() ) )
return;
partNum = mAttachementMap[mCurrentURL.path()];
}
@@ -1167,7 +1167,7 @@ void ArticleWidget::slotURLClicked( const KURL &url, bool forceOpen)
if ( !c )
return;
- // TODO: replace with message box as done in KMail
+ // TODO: tqreplace with message box as done in KMail
KNConfigManager *cfgMgr = knGlobals.configManager();
if ( forceOpen || cfgMgr->readNewsViewer()->openAttachmentsOnClick() )
diff --git a/knode/headerview.cpp b/knode/headerview.cpp
index ede75bb6..0c2e0622 100644
--- a/knode/headerview.cpp
+++ b/knode/headerview.cpp
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, Qt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, Qt::AlignRight );
// due to our own column text squeezing we need to repaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),
TQT_SLOT(slotSizeChanged(int, int, int)) );
@@ -146,7 +146,7 @@ void KNHeaderView::setActive( TQListViewItem *i )
if ( mActiveItem ) {
mActiveItem->setActive( false );
- repaintItem( mActiveItem );
+ tqrepaintItem( mActiveItem );
mActiveItem = 0;
}
@@ -534,7 +534,7 @@ TQDragObject* KNHeaderView::dragObject()
void KNHeaderView::slotSizeChanged( int section, int, int newSize )
{
- viewport()->repaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
+ viewport()->tqrepaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
}
@@ -601,14 +601,14 @@ void KNHeaderViewToolTip::maybeTip( const TQPoint &p )
if ( !item->showToolTip( column ) )
return;
- const TQRect itemRect = listView->itemRect( item );
- if ( !itemRect.isValid() )
+ const TQRect tqitemRect = listView->tqitemRect( item );
+ if ( !tqitemRect.isValid() )
return;
const TQRect headerRect = listView->header()->sectionRect( column );
if ( !headerRect.isValid() )
return;
- tip( TQRect( headerRect.left(), itemRect.top(), headerRect.width(), itemRect.height() ),
+ tip( TQRect( headerRect.left(), tqitemRect.top(), headerRect.width(), tqitemRect.height() ),
TQStyleSheet::escape( item->text( column ) ) );
}
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, Qt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, Qt::AlignRight );
- // due to our own column text squeezing we need to repaint on column resizing
+ // due to our own column text squeezing we need to tqrepaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),
diff --git a/knode/knglobals.h b/knode/knglobals.h
index 605f956c..72ffa1f0 100644
--- a/knode/knglobals.h
+++ b/knode/knglobals.h
@@ -75,8 +75,8 @@ class KDE_EXPORT KNGlobals {
KNScoringManager *scoringManager();
KNMemoryManager *memoryManager();
- /** forwarded to top->setStatusMsg() if available */
- void setStatusMsg(const TQString& text = TQString::null, int id = SB_MAIN);
+ /** forwarded to top->seStatusMsg() if available */
+ void seStatusMsg(const TQString& text = TQString::null, int id = SB_MAIN);
private:
KSharedConfig::Ptr c_onfig;